;
; 'Funky Stars'
;
; A simple intro written for the 
; Intro Creation Competition 2019
;
; Released by C64 Crap Debunk in 2019
;
; c64crapdebunk.wordpress.com
; www.cosine.org.uk
;
; Code, graphics and music by aNdy/Cosine/AL
;
; Thanks to T.M.R/Cosine/C64CD
;
; This source is formatted for the ACME cross assembler
; which can be downloaded from...
; http://sourceforge.net/projects/acme-crossass/
;
; The final build was compressed and squished using
; Exomizer 2 which can be downloaded from...
; http://hem.bredband.net/magli143/exo/
;
; Questions about this code or about how the binaries
; were created can be asked by emailing aNdy...
; andy@cosine.org.uk
;
; Any spelling mistakes in the code comments below
; are the fault of someone else.  Honest...  ;)
;

; code begins now! ===============================

; the name and file format for the assembled program

		!to "c64cdicc.prg",cbm

; drag in some charset, sprite and music binaries!	

		* = $0400
		!binary "data/screen.prg"

		* = $1000
music	!binary "data/music.prg",,2

		* = $0800
		!binary "data/charset.chr"

		* = $2000
		!binary "data/sprites.spr"
		
; position of the raster interrupt(s) on-screen

raster_1_pos	= $00			; start of screen
raster_2_pos	= $52			; middle-ish of PETSCII logo
raster_3_pos	= $79			; start of blue fade splitter
raster_4_pos	= $7d			; start of credit text
raster_5_pos	= $b2			; start of square scroll
raster_6_pos	= $e1			; start of bottom text plotter


; some label assignments (variables)

raster_num			= $50		; raster counter stores which split we are working in
sync				= $51		; interupt sync variable
colourwash_count	= $52		; colour pulse counter for wash effect
colourwash_timer	= $53		; colour pulse timer for wash effect
scroll_x			= $54		; title scroller screen position
scroll_pos			= $55		; titles scroller position - $02 bytes used
bkgd_timer			= $57		; timer for char animation
msb_flag1			= $58		; flag for setting top starfield sprites msb
msb_flag2			= $59		; flag for setting bot starfield sprites msb
anim_timer			= $5a		; timer for sprite animation


; entry point for the code

		* = $2c00				

; stop interrupts, disable the roms and set up nmi and irq interrupt pointers		
				
code_entry

		sei						; disable maskable IRQs
		
		lda #$35				; kill EVERYTHING (MWHAHA!) except $f000-$ffff
		sta $01
		
; setup nmi

		lda #<nmi				; some nmi stuff
		sta $fffa
		lda #>nmi
		sta $fffb
		
; setup irq's

		lda #<int				; some irq stuff
		sta $fffe
		lda #>int
		sta $ffff

		lda #$7f
		sta $dc0d				; disable timer interrupts which can be generated by the two CIA chips
		sta $dd0d				; the kernal uses such an interrupt to flash the cursor and scan
								; the keyboard, so we better stop it

		lda $dc0d				; by reading this two registers we negate any pending CIA irqs.
		lda $dd0d				; if we don't do this, a pending CIA irq might occur after we
								; finish setting up our irq. we don't want that to happen.

		lda #raster_1_pos		; starting point of raster on screen ($00)
		sta $d012

		lda #$1b				; as there are more than 256 rasterlines, the topmost bit of $d011 serves as
		sta $d011				; the 9th bit for the rasterline we want our irq to be triggered.
		
		lda #$01
		sta $d019				; clear interupt bit
		sta $d01a				; tell vicii to generate interupt

		lda #$35				; turn off basic and kernal rom thus
		sta $01					; c64 now sees RAM everywhere except at $d000-$e000
		
		lda #$12				; use our custom font charset, ta very much!
		sta $d018

		cli

; first run screen setup =========================		
	
; setup for the very first run by clearing the colour ram,
; then reading data from the colour ram tables
; (at the bottom of this code) for PETSCII logo
; and checker board blocks
	
        lda #$00				; load 0 for black
		sta $d021				; store to background! change colour!
		sta $d020				; store to border! change colour!

		ldx #$00				; zero x register		
clrcolram						; clear colour ram loop!
		sta $d800,x
		sta $d900,x
		sta $da00,x
		sta $dae8,x		
		inx
		bne clrcolram
		
		ldx #$00				; zero x register
logo_colram_loop				; load whatever's in the logo colour
		lda logo_colram,x		; ram table and write to these
		sta $d800,x				; locations for the C64CD logo
		lda logo_colram+180,x
		sta $d800+180,x	
		inx
		cpx #$b4				; done 250 writes?
		bne logo_colram_loop	; all written? no? loop back!
		
		ldx #$00				; zero x register
chkboard_colram_loop			; load whatever is in the check board
		lda checker_colram,x	; colour ram table and write to the
		sta $daa8,x				; colour ram at these locations
		sta	$dad0,x				; for the checker board
		sta $daf8,x
		sta $db20,x
		inx
		cpx #$28					; done 40 writes?
		bne chkboard_colram_loop	; all written? no? loop back!		

		
; reset the message scroller for first run

		jsr scroll_reset		; reset 'scroller' subroutine
		
		lda #$50
		sta scroll_x

; prepare the music for first run		
		
		lda #$00				; setup the driver to
		jsr music+$00			; play the title music
		
; set up raster handler for first raster at the top of the screen
		
		lda #$01
		sta raster_num
		
; main loop code =========================================

mainloop
								; call these subroutines...
		jsr sync_wait			; wait until irq finishes!
		jsr write_message		; write the scroller message
		
		lda $dc01				; load spacebar register
		cmp #$ef				; is space pressed?
		beq *+$05				; yes? jump down to reset the 64...

		jmp mainloop			; no? go back to 'mainloop' up by there
								; and call the subroutines again!
								
; space has been pressed so reset some registers

		sei
		lda #$37
		sta $01

		lda #$00
		sta $d011
		sta $d020
		sta $d021
		sta $d418

; reset the C64 (a linker could go here...)

		jmp $fce2								

										
; subroutines called from above code =====================		
		
; irq sync wait subroutine ---------------------------------- 
	   	 
sync_wait						; wait for sync update in irq code!
		lda #$00				; waits until the sync flag is
		sta sync				; set at the end of the interupt
sw_loop							; code further down.
		cmp sync				; no code in the main loop above
		beq sw_loop				; is executed until the interupt
								; has run it's course!
		rts

		
; update 'scrolling' message subroutine --------------------- 
		
write_message
	
		ldx scroll_x
		cpx #$28
		bcs scroll_cnt

; fetch a character from the text table

scroll_read

		ldy #$00
		lda (scroll_pos),y
		bne scroll_write
		
		jsr scroll_reset
		
		jmp scroll_read

; write that character to the screen
		
scroll_write

		sta $0798,x

; update the text position

		inc scroll_pos+$00
		bne *+$04
		inc scroll_pos+$01

; store the current text position		
		
scroll_cnt

		inx
		stx scroll_x
		
		rts						; return to where this was called from

; reset the scroll message		
				
scroll_reset

		lda #<greet_text
		sta scroll_pos+$00
		lda #>greet_text
		sta scroll_pos+$01
		
		rts						; return to where this was called from
		
		
; end subroutines =====================================		
			

; IRQ interrupt code =================================

int
		pha  
		txa
		pha
		tya
		pha
		
		lda $d019
		and #$01
		sta $d019
		bne intr_trigd
		
		jmp irq_exit			; no interupt triggered? exit irq code!
		
; an interrupt has triggered!?!
; which split should we run? let's check...

intr_trigd

		lda raster_num			; load up the raster_num variable
		
		cmp #$02				; is it set to '2'?
		bne *+$05				; no? then jump down to check for '3'
		jmp irq_rout2			; yes? jump down to irq_rout2!

		cmp #$03				; is the raster_num set to '3'?
		bne *+$05				; no? jump down and run irq_rout1!
		jmp irq_rout3			; yes? jump down to irq_rout3!

		cmp #$04				; is the raster_num set to '4'?
		bne *+$05				; no? jump down and run irq_rout1!
		jmp irq_rout4			; yes? jump down to irq_rout4!
		
		cmp #$05				; is the raster_num set to '5'?
		bne *+$05				; no? jump down and run irq_rout1!
		jmp irq_rout5			; yes? jump down to irq_rout5!
		
		cmp #$06				; is the raster_num set to '6'?
		bne *+$05				; no? jump down and run irq_rout1!
		jmp irq_rout6			; yes? jump down to irq_rout6!										

; raster split 1 code -------------------------------

irq_rout1						; top section of the screen

; set interrupt handler ready for split 2

		lda #$02				; next run through this interupt code,
		sta raster_num			; split 2 should execute, a bit
		lda #raster_2_pos		; further down...
		sta $d012	

		lda #$0e				; change colour to lt blue border
		sta $d020
		lda #$00				; and black background
		sta $d021
		
; now some star sprites for the top part of the logo
 
		lda #$ff				; turn on..
		sta $d015				; all 8 sprites!
		sta $d01b				; AND put them behind the logo!		
		lda #$00				; make these sprites
		sta $d01c				; hires

		ldx #$00
		ldy #$00
draw_sprites_t1					; lets draw the top part of the starfield
		lda t1_sprite_x,x		; load in the sprite x position from the table
		sta $d000,y				; store in the sprites x register
		lda t1_sprite_msb		; check if we're in the MSB
		sta $d010			
		lda t1_sprite_y,x		; pull in the y position
		sta $d001,y
		lda #$07				; make the stars yellow
		sta $d027,x
		lda t1_sprite_def,x		; pull in the start definitions from the defs table
		sta $07f8,x
		iny
		iny
		inx
		cpx #$08
		bne draw_sprites_t1
			
		ldx #$00
		lda #$01
		sta msb_flag1			; set the temp value used for MSB juggling
reposition_sprites_t1
		lda t1_sprite_x,x		; pull in the x position of the sprites
		sbc t1_sprite_speed,x	; and subtract whatever is in the speed table
		sta t1_sprite_x,x		; then store back to the x position table

		bcs no_msb_t1			; skip the MSB wrangling if carry isn't set

		lda t1_sprite_msb		; read the current MSB value
		eor msb_flag1			; toggle the bit for the sprite being processed
		sta t1_sprite_msb		; write the current MSB value

no_msb_t1
		asl msb_flag1			; shift the bit used for toggling MSB up for the next pass
		inx
		cpx #$08				
		bne reposition_sprites_t1		

; split 1 is done, exit irq interrupt		
					
		jmp irq_exit			; now exit the interupt!
		
; raster split 2 code ------------------------------------

irq_rout2

; set interrupt handler ready for split 3
	
		lda #$03
		sta raster_num
		lda #raster_3_pos
		sta $d012
		
; now recycle star sprites for the bottom part of the logo
 
		lda #$ff				; same as the code in raster split 1
		sta $d015				; see up there ^ for explanation!
		sta $d01b	
		lda #$00
		sta $d01c

		ldx #$00
		ldy #$00
draw_sprites_t2
		lda t2_sprite_x,x
		sta $d000,y
		lda t2_sprite_msb
		sta $d010			
		lda t2_sprite_y,x
		sta $d001,y
		lda #$07
		sta $d027,x
		lda t2_sprite_def,x
		sta $07f8,x
		iny
		iny
		inx
		cpx #$08
		bne draw_sprites_t2
		
		
		ldx #$00
		lda #$01
		sta msb_flag2
reposition_sprites_t2
		lda t2_sprite_x,x
		sbc t2_sprite_speed,x
		sta t2_sprite_x,x

		bcs no_msb_t2

		lda t2_sprite_msb
		eor msb_flag2
		sta t2_sprite_msb

no_msb_t2
		asl msb_flag2
		inx
		cpx #$08
		bne reposition_sprites_t2			
		
		
; split 2 is done, exit irq interrupt

		jmp irq_exit		
		
; raster split 3 code ------------------------------------

irq_rout3

; set interrupt handler ready for split 4
	
		lda #$04
		sta raster_num
		lda #raster_4_pos
		sta $d012		
		
		lda #$0e				; change colour to lt blue border
		sta $d020				; for blue fade splitter		
		sta $d021

		ldx #$00
blue_fadeout_loop
		lda blue_fadeout,x
		sta $d020
		sta $d021
		ldy blue_fadeout_tmr,x
		dey
		bne *-$01
		inx
		cpx #$08
		bne blue_fadeout_loop	
		
; split 3 is done, exit irq interrupt

		jmp irq_exit			

; raster split 4 code ------------------------------------

irq_rout4

; set interrupt handler ready for split 5		

		lda #$05
		sta raster_num
		lda #raster_5_pos
		sta $d012	

		lda #$00				; change colour to black border
		sta $d020				; for the rest of the screen		
		sta $d021		
						
; call music player	and play dat choon!
		
		jsr music+$03			; play tune!

; colour wash effect for middle of the screen text lines

		ldx #$00
colourwash_loop
		lda colourwash_off,x
		clc
		adc colourwash_count
		and #$0f
		tay
		lda colourwash_rainbow,y
		sta $d9b8,x
		sta $da08,x
		sta $da58,x
		inx
		cpx #$28
		bne colourwash_loop

		ldx colourwash_timer
		inx
		cpx #$03
		bcc exit_wash
		inc colourwash_count
		ldx #$00
exit_wash	
		stx colourwash_timer
		
; split 4 is done, exit irq interrupt

		jmp irq_exit

; raster split 5 code ------------------------------------

irq_rout5

; set interrupt handler ready for split 6

		lda #$06
		sta raster_num
		lda #raster_6_pos
		sta $d012
		
; now recycle yet more sprites to draw over the checker board
 
		lda #$ff				; turn on..
		sta $d015				; all 8 sprites!
		lda #$00				; make these sprites
		sta $d01c				; hires
		sta $d01b		

		ldx #$00
		ldy #$00
draw_sprites_icc				; lets draw icc logo sprites
		lda icc_sprite_x,x		; load in the x pos from the table
		sta $d000,y				; store in the sprites x register
		lda #$c0				; only sprite 7 & 8 are in the MSB!
		sta $d010		
		lda icc_sprite_y,x		; pull in y positions
		sta $d001,y
		lda #$00				; black sprites please!
		sta $d027,x
		lda icc_sprite_def,x	; pull in sprite definitions
		sta $07f8,x
		iny
		iny
		inx
		cpx #$08
		bne draw_sprites_icc
		
; icc logo sprite animation routine!	
				
		ldx anim_timer			; load up the anim_timer
		inx						; increase it by '1'
		cpx #$03				; is the timer equal to '4' yet?
		bne sp_anim_skip		; no? don't update animation!
								; yes? better do some animation then!
		ldx #$00
spr_anim_loop
		lda icc_sprite_def,x	; pull in the current definition
		clc						; clear carry
		adc #$01				; add 1!
		cmp icc_sprite_anime,x	; does current definition = end animation?
		bne spr_anim_skip		; no? go down to skip label
		lda icc_sprite_anims,x	; yes? load start animation definition
spr_anim_skip
		sta icc_sprite_def,x	; store to current sprite definition
		inx
		cpx #$08				; all 8 sprite done?
		bne spr_anim_loop		; no? go back up to loop							
								; yes?
		ldx #$00				; load x register with '0'
sp_anim_skip					; to reset anim_timer and...	
		stx anim_timer			; store x register to anim_timer								
		
; split 5 is done, exit irq interrupt

		jmp irq_exit
		
; raster split 6 code ------------------------------------

irq_rout6

; set interrupt handler ready for split 1		

		lda #$01
		sta raster_num
		lda #raster_1_pos
		sta $d012

		ldx #$07				; a little delay to ensure
		dex						; the colour splitter
		bne *-$01				; doesn't glitch!
		
; draw colour splits for this interrupt		
		
		ldx #$00
scroller_splits_loop
		lda scroller_splits,x
		sta $d021
		nop
		nop
		ldy scroller_splits_tmr,x
		dey
		bne *-$01
		inx
		cpx #$17
		bne scroller_splits_loop			
		
; char animation routine	

		ldy bkgd_timer			; load up the bkgrd anim timer
		iny						; increase it by '1'
		cpy #$02				; is the timer equal to '4' yet?
		bne bkgrd_anim_skip		; no? don't update animation!
								; yes? better do some animation then!
	    ldx #$00				; zero x register
pipe_anim_loop
		lda $0c00,x				; load mem location of the pipe char
		asl
		rol $0c00,x				; shift byte of the char to the left				
		inx
		cpx #$08				; all 8 bytes done?
		bne pipe_anim_loop		; no? do the next byte then!							
								; yes?
		ldy #$00				; load y register with '0'
bkgrd_anim_skip					; to reset bkgrd anim timer and...	
		sty bkgd_timer			; store y register to bkgrd anim timer			
			
; set sync variable for main line code synchronisation

set_sync
		lda #$01				; set the sync flag to '1'		
		sta sync				; so the main code runs!
		
; restore registers and exit irq interrupt

irq_exit

		pla
		tay
		pla
		tax
		pla
nmi		rti

; end irq interrupt code =============================


; all data tables live here! ===============================

; colour wash data tables for text colour cycling

colourwash_off
		!byte $00,$01,$02,$01,$00,$01,$02,$01
		!byte $08,$07,$06,$05,$04,$03,$02,$04
		!byte $06,$08,$0a,$0c,$0e,$00,$0f,$0e
		!byte $0d,$0c,$0b,$0a,$09,$08,$07,$06
		!byte $0c,$0c,$0b,$0a,$0b,$0c,$0c,$0e		
					
colourwash_rainbow
		!byte $06,$02,$04,$05,$03,$07,$0c,$0f
		!byte $0b,$01,$0c,$07,$03,$05,$04,$06
		
; sprite table for first set of stars in title logo

t1_sprite_x		!byte $05,$64,$32,$f0,$e3,$b4,$a9,$e8
t1_sprite_y		!byte $3c,$3c,$3c,$3c,$3c,$3c,$3c,$3c
t1_sprite_def	!byte $80,$81,$82,$83,$84,$85,$86,$87
t1_sprite_speed	!byte $05,$04,$03,$03,$02,$07,$06,$08
t1_sprite_msb	!byte $00,$00,$00,$00,$00,$00,$00,$00

; sprite table for second set of stars in title logo

t2_sprite_x		!byte $f0,$e3,$b4,$a9,$e8,$05,$64,$32
t2_sprite_y		!byte $59,$59,$59,$59,$59,$59,$59,$59
t2_sprite_def	!byte $80,$81,$82,$83,$84,$85,$86,$87
t2_sprite_speed	!byte $07,$06,$08,$05,$04,$03,$03,$02
t2_sprite_msb	!byte $00,$00,$00,$00,$00,$00,$00,$00

; sprite table for icc logo

icc_sprite_x		!byte $2c,$4d,$6c,$ac,$cc,$ec,$0d,$2c
icc_sprite_y		!byte $bf,$bf,$bf,$bf,$bf,$bf,$bf,$bf
icc_sprite_def		!byte $88,$90,$94,$a0,$a6,$a8,$8a,$ab
icc_sprite_anims	!byte $88,$90,$90,$a0,$a0,$a8,$88,$a8
icc_sprite_anime	!byte $90,$a0,$a0,$a8,$a8,$b0,$90,$b0

; C64CD logo colour ram table

logo_colram 
!byte $0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E
!byte $0E,$03,$06,$06,$06,$0E,$0E,$0E,$0E,$03,$06,$06,$06,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$03,$06,$0E,$0E,$0E,$03,$06,$06,$06,$0E,$0E,$0E,$03,$06,$06,$06,$06,$0E,$0E
!byte $0E,$06,$04,$06,$06,$0E,$0E,$0E,$0E,$06,$04,$06,$06,$0E,$0E,$0E,$06,$0E,$0E,$0E,$0E,$04,$06,$0E,$0E,$0E,$06,$04,$06,$06,$0E,$0E,$0E,$0E,$06,$0E,$0E,$04,$06,$0E
!byte $0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$04,$04,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0B,$0B,$0B
!byte $0E,$04,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$04,$0E,$0E,$04,$04,$0E,$0E,$04,$04,$0E,$0E,$0E,$04,$04,$0E,$0E,$0E,$04,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$04,$0E,$0E,$04,$04,$04
!byte $01,$0E,$01,$0E,$0E,$0E,$0E,$0E,$01,$0E,$0E,$0E,$0E,$01,$06,$0E,$0E,$06,$06,$06,$01,$0E,$0E,$06,$0E,$01,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$01,$0E,$0E,$0E,$0E,$01,$06
!byte $01,$04,$06,$06,$06,$06,$0E,$0E,$01,$04,$06,$06,$06,$01,$04,$0E,$0E,$0E,$0E,$0E,$0E,$04,$0E,$0E,$0E,$01,$04,$06,$06,$06,$06,$0E,$0E,$01,$04,$06,$06,$06,$01,$04
!byte $0E,$06,$06,$06,$06,$06,$0E,$0E,$0E,$06,$06,$06,$06,$06,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$06,$06,$0E,$0E,$0E,$06,$06,$06,$06,$06,$0E,$0E,$06,$06,$06,$06,$06,$06,$0E
!byte $0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E,$0E

; checker board pattern colour ram table

checker_colram
	!byte $05,$05,$05,$05,$0d,$0d,$0d,$0d
	!byte $05,$05,$05,$05,$0d,$0d,$0d,$0d
	!byte $05,$05,$05,$05,$0d,$0d,$0d,$0d
	!byte $05,$05,$05,$05,$0d,$0d,$0d,$0d
	!byte $05,$05,$05,$05,$0d,$0d,$0d,$0d
	!byte $05,$05,$05,$05,$0d,$0d,$0d,$0d
	!byte $05,$05,$05,$05,$0d,$0d,$0d,$0d
	!byte $05,$05,$05,$05,$0d,$0d,$0d,$0d						

; text data for the rolling greetings

greet_text
		!scr "????COMMODORE?SIXTY?FOUR?CRAP?DEBUNK????"
		!scr "PRESENTS?A?VERY?SIMPLE?<>K?ENTRY?FOR?THE"
		!scr "????INTRO?CREATION?COMPETITION?MMXIX????"
		!scr "????????????????????????????????????????"			
		!scr "????CODE=?GRAPHICS?AND?MUSIC?BY?#/$%????"
		!scr "????????????????????????????????????????"			
		!scr "?????HUGE?THANKS?AS?ALWAYS?TO?T'M'R?????"
		!scr "????????????????????????????????????????"
		!scr "????THIS?INTRO?IS?CALLED?FUNKY?STARS????"		
		!scr "SINCE?THIS?SID?IS?A?COVER?OF?THE?CLASSIC"
		!scr "?TEN?CHANNEL?MOD???FUNKY?STARS???A'K'A'?"
		!scr "???HYBRID?SONG???BY?QUAZAR?OF?SANXION???"
		!scr "????????????????????????????????????????"			
		!scr "???GREETS?TO?ALL?THE?USUAL?PEOPLE?AND???"
		!scr "?GROUPS'''??YOU?KNOW?WHO?YOU?ALL?ARE'''?"
		!scr "????????????????????????????????????????"				
		!scr "???PLEASE?VISIT?THE?C>*CD?WORLD?HQ'''???"	
		!scr "????WWW'C>*CRAPDEBUNK'WORDPRESS'COM?????"
		!scr "????????????????????????????????????????"		
							
		!byte $00		; end of text marker	

; colour / timer data tables for colour splitters		
		
blue_fadeout
		!byte $0e,$04,$06,$00,$06,$00,$00,$00

blue_fadeout_tmr
		!byte $0a,$08,$08,$08,$08,$08,$08,$08
		
scroller_splits
		!byte $0c,$0f,$01,$0f,$0c,$0b,$0b,$00		
		!byte $02,$0a,$07,$01,$03,$0e,$06,$00	
		!byte $0c,$0f,$01,$0f,$0c,$0b,$0b,$00	
				
scroller_splits_tmr
		!byte $01,$08,$08,$08,$08,$08,$08,$08	
		!byte $01,$08,$08,$08,$08,$08,$08,$08
		!byte $01,$08,$08,$08,$08,$08,$08,$08					
	
; end of code!!! ========================================================================
